/****************************************************************************
 |
 |  (C) Copyright 2001, 2004-2010, 2014-2015  Novell, Inc.
 |  All Rights Reserved.
 |
 | Permission is hereby granted, free of charge, to any person obtaining
 | a copy of this software and associated documentation files (the "Software"),
 | to deal in the Software without restriction, including without limitation 
 | the rights to use, copy, modify, merge, publish, distribute, sublicense,
 | and/or sell copies of the Software, and to permit persons to whom the
 | Software is furnished to do so, subject to the following conditions:
 |
 | The above copyright notice and this permission notice shall be included in
 | all copies or substantial portions of the Software.
 |
 | THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 | IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 | FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 | AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 | LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 | OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 | SOFTWARE.
 |
 |***************************************************************************
 |
 | NOVELL IDENTITY TRANSLATOR (NIT) Userspace Library (libnit).
 |
 | $Author: mkiran $
 | $Date: 2015-04-02 17:10:33 +0530 (Thu, 02 Apr 2015) $
 |
 | $RCSfile$
 | $Revision: 0001 $
 |
 | File: nitlibext.h
 |
 | Desc: libnit - Novell Indentity Traslator Library.
 +-------------------------------------------------------------------------*/

#ifndef __INCLUDE_NITLIBEXT_H__
#define __INCLUDE_NITLIBEXT_H__

#include <stdint.h>
#include <novell-nit/niterr.h>

#pragma pack(1)

#ifdef  __cplusplus
extern "C" {
#endif

/*---------------------------------------------------------------------------
** Common nit types.
*/
/** *********************** GUID type (16 bytes) ************************* **/

typedef struct
{
	uint32_t timeLow;
	uint16_t timeMid;
	uint16_t timeHighAndVersion;
	uint8_t  clockSeqHighAndReserved;
	uint8_t  clockSeqLow;
	uint8_t  node[6];
} NIT_GUID_t;


#define NIT_SID_MAXSUBAUTHS 15 /* max sub authorities in a SID */
typedef struct
{
	uint8_t sid_rev_num;
	uint8_t num_auths;
	uint8_t id_auth[6];
	uint32_t	sub_auths[NIT_SID_MAXSUBAUTHS];
} NIT_SID_t;


/****************************************************************************
** Function: LIBNIT_ADSIDToName
**
** Description: Finds name associated to given AD SID.
**
** Parameters:
**		adsid : Points to the structure that is passed as parameter. 
**		name  : Points to a NULL-terminated string.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
**
** NOTE: Caller has to free the memory pointed by name.
****************************************************************************/
int LIBNIT_ADSIDToName(NIT_SID_t *adsid, char **name);


/****************************************************************************
** Function: LIBNIT_NameToADSID 
**
** Description: Finds AD SID associated to given AD name.
**
** Parameters:
**		name : Points to the structure that is passed as parameter. 
**		adsid : Points to a structure.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
****************************************************************************/
int LIBNIT_NameToADSID(char *name, NIT_SID_t *adsid);


/****************************************************************************
** Function: LIBNIT_SIDToString
**
** Description: Converts given AD SID format to string.
**
** Parameters:
**		adsid : Points to the structure that is passed as parameter. 
**		sidstr : Points to a NULL-terminated string.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
****************************************************************************/
int LIBNIT_SIDToString(const NIT_SID_t *adsid, char *sidstr);


/****************************************************************************
** Function: LIBNIT_StringToSID
**
** Description: Converts given string to AD SID format.
**
** Parameters:
**		sidstr : Points to the string that is passed as parameter. 
**		adsid : Points to the structure.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
****************************************************************************/
int LIBNIT_StringToSID(const char *sidstr, NIT_SID_t *adsid);


/****************************************************************************
** Function: LIBNIT_EDIRDNToGUID
**
** Description: Finds edir GUID associated to given edir dn.
**
** Parameters:
**		edirdn : Points to the string that is passed as parameter. 
**		edirguid : Points to the structure. 
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
****************************************************************************/
int LIBNIT_EDIRDNToGUID(char *edirdn, NIT_GUID_t *edirguid);


/****************************************************************************
** Function: LIBNIT_GUIDToEDIRDN
**
** Description: Finds edir dn associated to given edir GUID.
**
** Parameters:
**		edirguid : Points to the structure that is passed as parameter. 
**		edirdn : Points to a NULL-terminated string.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
**
** NOTE: Caller has to free the memory pointed by edirdn.
****************************************************************************/
int LIBNIT_GUIDToEDIRDN(NIT_GUID_t *edirguid, char **edirdn);


/****************************************************************************
** Function: LIBNIT_GUIDToString
**
** Description: Converts given edir GUID format to string.
**
** Parameters:
**		edirguid : Points to the structure that is passed as parameter. 
**		guidstr : Points to a NULL-terminated string.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
****************************************************************************/
int LIBNIT_GUIDToString(const NIT_GUID_t *edirguid, char *guidstr);


/****************************************************************************
** Function: LIBNIT_StringToGUID 
**
** Description: Converts given string to edir GUID format.
**
** Parameters:
**		guidstr : Points to the string that is passed as parameter. 
**		edirguid  : Points to a structure.
**
** Return Values:
** The return status should either be NIT_SUCCESS or a valid NIT error code.
****************************************************************************/
int LIBNIT_StringToGUID(const char *guidstr, NIT_GUID_t *edirguid);


#ifdef  __cplusplus
}
#endif

#pragma pack()

#endif /* __INCLUDE_NITLIBEXT_H__ */
